@@ -1,5 +1,5 @@
 /*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010
+    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011
     Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
@@ -32,12 +32,12 @@
 // Looks for three black sections in column hcenter()  n, then tests if
 // upper and lower gaps are open to the right or to the left
 //
-int Features::test_235Esz( const Charset & charset ) const throw()
+int Features::test_235Esz( const Charset & charset ) const
   {
   const int csize = 3;
   const int ucoff[csize] = { 0, -1, +1 };
   const int lcoff[3*csize] = { 0, -1, +1, -1, 0, +1, +1, 0, -1 };
-  const Blob & b = *blob_;
+
   if( b.width() < 9 || b.height() > 3 * b.width() ||
       bp.minima( b.height() / 2 ) > 1 ) return 0;
 
@@ -150,10 +150,8 @@ int Features::test_235Esz( const Charset & charset ) const throw()
   }
 
 
-int Features::test_CEFIJLlT( const Charset & charset ) const throw()
+int Features::test_CEFIJLlT( const Charset & charset ) const
   {
-  const Blob & b = *blob_;
-
   if( tp.minima( b.height() / 4 ) != 1 || bp.minima( b.height() / 4 ) != 1 )
     return 0;
 
@@ -323,10 +321,8 @@ int Features::test_CEFIJLlT( const Charset & charset ) const throw()
   }
 
 
-int Features::test_c() const throw()
+int Features::test_c() const
   {
-  const Blob & b = *blob_;
-
   if( lp.isconvex() || lp.ispit() )
     {
     int urow = b.seek_top( b.vcenter(), b.hcenter() );
@@ -357,10 +353,8 @@ int Features::test_c() const throw()
   }
 
 
-int Features::test_frst( const Rectangle & charbox ) const throw()
+int Features::test_frst( const Rectangle & charbox ) const
   {
-  const Blob & b = *blob_;
-
   if( bp.minima( b.height() / 4 ) != 1 || tp.minima( b.height() / 2 ) != 1 ||
       bp.minima( b.height() / 2 ) != 1 ) return 0;
   const int noise = ( std::min( b.height(), b.width() ) / 30 ) + 1;
@@ -472,10 +466,8 @@ int Features::test_frst( const Rectangle & charbox ) const throw()
   }
 
 
-int Features::test_G() const throw()
+int Features::test_G() const
   {
-  const Blob & b = *blob_;
-
   if( lp.isconvex() || lp.ispit() )
     {
     int col = 0, row = 0;
@@ -511,10 +503,8 @@ int Features::test_G() const throw()
 
 // Common feature: U-shaped top of character
 //
-int Features::test_HKMNUuvwYy( const Rectangle & charbox ) const throw()
+int Features::test_HKMNUuvwYy( const Rectangle & charbox ) const
   {
-  const Blob & b = *blob_;
-
   if( tp.minima( b.height() / 5 ) == 2 && tp.minima( b.height() / 4 ) == 2 &&
       tp.minima( b.height() / 2 ) <= 3 && tp.isctip() )
     {
@@ -615,9 +605,8 @@ int Features::test_HKMNUuvwYy( const Rectangle & charbox ) const throw()
 // Looks for the nearest frontier in column hcenter(), then tests if
 // gap is open downwards (except for 'x')
 //
-int Features::test_hknwx( const Rectangle & charbox ) const throw()
+int Features::test_hknwx( const Rectangle & charbox ) const
   {
-  const Blob & b = *blob_;
   const int m8 = tp.minima( b.height() / 8 );
 
   if( m8 == 2 && bp.minima( b.height() / 2 ) == 1 &&
@@ -662,9 +651,8 @@ int Features::test_hknwx( const Rectangle & charbox ) const throw()
 // Looks for four black sections in column hcenter()  1, then tests if
 // upper gap is open to the right and lower gaps are open to the left
 //
-int Features::test_s_cedilla() const throw()
+int Features::test_s_cedilla() const
   {
-  const Blob & b = *blob_;
   int urow2 = 0, urow3 = 0, urow4 = 0, col, black_section = 0;
 
   for( col = b.hcenter() - 1; col <= b.hcenter() + 1; ++col )
@@ -693,10 +681,8 @@ int Features::test_s_cedilla() const throw()
   }
 
 
-bool Features::test_comma() const throw()
+bool Features::test_comma() const
   {
-  const Blob & b = *blob_;
-
   if( b.holes() || b.height() <= b.width() || b.height() > 3 * b.width() )
     return false;
 
@@ -717,9 +703,8 @@ bool Features::test_comma() const throw()
   }
 
 
-int Features::test_easy( const Rectangle & charbox ) const throw()
+int Features::test_easy( const Rectangle & charbox ) const
   {
-  const Blob & b = *blob_;
   int code = test_solid( charbox );
   if( code ) return code;
 
@@ -739,9 +724,8 @@ int Features::test_easy( const Rectangle & charbox ) const throw()
 // Recognizes single line, non-rectangular characters without holes.
 // '/<>\^`
 //
-int Features::test_line( const Rectangle & charbox ) const throw()
+int Features::test_line( const Rectangle & charbox ) const
   {
-  const Blob & b = *blob_;
   int slope1, slope2;
 
   if( tp.minima() != 1 ) return 0;
@@ -803,9 +787,8 @@ int Features::test_line( const Rectangle & charbox ) const throw()
   }
 
 
-int Features::test_solid( const Rectangle & charbox ) const throw()
+int Features::test_solid( const Rectangle & charbox ) const
   {
-  const Blob & b = *blob_;
   if( b.holes() ) return 0;
 
   if( b.height() >= 5 && b.width() >= 5 )
