@@ -1,5 +1,5 @@
 /*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010
+    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011
     Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
@@ -32,9 +32,8 @@
 // Tests if the lower half of character is open to the left, to the right,
 // and/or to the bottom
 //
-int Features::test_49ARegpq( const Rectangle & charbox ) const throw()
+int Features::test_49ARegpq( const Rectangle & charbox ) const
   {
-  const Blob & b = *blob_;
   const Bitmap & h = b.hole( 0 );
 
   if( bp.minima( b.height() / 10 + 1 ) == 2 && bp.isctip() && tp.minima() == 1 )
@@ -96,9 +95,8 @@ int Features::test_49ARegpq( const Rectangle & charbox ) const throw()
   }
 
 
-int Features::test_4ADQao( const Charset & charset, const Rectangle & charbox ) const throw()
+int Features::test_4ADQao( const Charset & charset, const Rectangle & charbox ) const
   {
-  const Blob & b = *blob_;
   const Bitmap & h = b.hole( 0 );
   int left_delta = h.left() - b.left(), right_delta = b.right() - h.right();
   const int noise = ( std::min( b.height(), b.width() ) / 30 ) + 1;
@@ -163,9 +161,8 @@ int Features::test_4ADQao( const Charset & charset, const Rectangle & charbox )
 // Tests if the upper half of character is open to the left, to the right,
 // and/or to the bottom
 //
-int Features::test_6abd( const Charset & charset ) const throw()
+int Features::test_6abd( const Charset & charset ) const
   {
-  const Blob & b = *blob_;
   const Bitmap & h = b.hole( 0 );
 
   if( 3 * h.width() < b.width() &&
