@@ -1,5 +1,5 @@
 /*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010
+    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011
     Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
@@ -28,6 +28,11 @@
 #include <cstring>
 #include <string>
 #include <vector>
+#if defined(__MSVCRT__) || defined(__OS2__) || defined(_MSC_VER)
+#include <fcntl.h>
+#include <unistd.h>
+#include <io.h>
+#endif
 
 #include "arg_parser.h"
 #include "common.h"
@@ -39,10 +44,10 @@
 
 namespace {
 
+const char * const Program_name = "GNU Ocrad";
+const char * const program_name = "ocrad";
+const char * const program_year = "2011";
 const char * invocation_name = 0;
-const char * const Program_name    = "GNU Ocrad";
-const char * const program_name    = "ocrad";
-const char * const program_year    = "2010";
 
 struct Input_control
   {
@@ -55,55 +60,57 @@ struct Input_control
     : scale( 0 ), threshold( -1 ),
       copy( false ), cut( false ), invert( false ), layout( false ) {}
 
-  bool read_cut_rectangle( const char * ptr ) throw();
-  bool set_threshold( const char * ptr ) throw();
+  bool parse_cut_rectangle( const char * const s ) throw();
+  bool parse_threshold( const char * const s ) throw();
   };
 
 
-void show_error( const char * msg, const int errcode = 0, const bool help = false ) throw()
+void show_error( const char * const msg, const int errcode = 0,
+                 const bool help = false ) throw()
   {
   if( verbosity >= 0 )
     {
-    if( msg && msg[0] != 0 )
+    if( msg && msg[0] )
       {
       std::fprintf( stderr, "%s: %s", program_name, msg );
-      if( errcode > 0 ) std::fprintf( stderr, ": %s", strerror( errcode ) );
+      if( errcode > 0 ) std::fprintf( stderr, ": %s", std::strerror( errcode ) );
       std::fprintf( stderr, "\n" );
       }
-    if( help && invocation_name && invocation_name[0] != 0 )
-      std::fprintf( stderr, "Try `%s --help' for more information.\n", invocation_name );
+    if( help && invocation_name && invocation_name[0] )
+      std::fprintf( stderr, "Try `%s --help' for more information.\n",
+                    invocation_name );
     }
   }
 
 
-bool Input_control::read_cut_rectangle( const char * ptr ) throw()
+bool Input_control::parse_cut_rectangle( const char * const s ) throw()
   {
-  int c = ltwh[0].parse( ptr );				// left
-  if( c && ptr[c] == ',' )
+  int c = ltwh[0].parse( s );				// left
+  if( c && s[c] == ',' )
     {
     int i = c + 1;
-    c = ltwh[1].parse( &ptr[i] );			// top
-    if( c && ptr[i+c] == ',' )
+    c = ltwh[1].parse( &s[i] );				// top
+    if( c && s[i+c] == ',' )
       {
-      i += c + 1; c = ltwh[2].parse( &ptr[i] );		// width
-      if( c && ptr[i+c] == ',' && ltwh[2] > 0 )
+      i += c + 1; c = ltwh[2].parse( &s[i] );		// width
+      if( c && s[i+c] == ',' && ltwh[2] > 0 )
         {
-        i += c + 1; c = ltwh[3].parse( &ptr[i] );	// height
+        i += c + 1; c = ltwh[3].parse( &s[i] );		// height
         if( c && ltwh[3] > 0 ) { cut = true; return true; }
         }
       }
     }
-  show_error( "invalid cut rectangle", 0, true );
+  show_error( "invalid cut rectangle.", 0, true );
   return false;
   }
 
 
-bool Input_control::set_threshold( const char * ptr ) throw()
+bool Input_control::parse_threshold( const char * const s ) throw()
   {
   Rational tmp;
-  if( tmp.parse( ptr ) && tmp >= 0 && tmp <= 1 )
+  if( tmp.parse( s ) && tmp >= 0 && tmp <= 1 )
     { threshold = tmp; return true; }
-  show_error( "threshold out of limits (0.0 - 1.0)", 0, true );
+  show_error( "threshold out of limits (0.0 - 1.0).", 0, true );
   return false;
   }
 
@@ -123,14 +130,14 @@ void show_help() throw()
   std::printf( "  -F, --format=<fmt>       output format (byte, utf8)\n" );
   std::printf( "  -i, --invert             invert image levels (white on black)\n" );
   std::printf( "  -l, --layout             perform layout analysis\n" );
-  std::printf( "  -o <file>                place the output into <file>\n" );
+  std::printf( "  -o, --output=<file>      place the output into <file>\n" );
   std::printf( "  -q, --quiet              suppress all messages\n" );
   std::printf( "  -s, --scale=[-]<n>       scale input image by [1/]<n>\n" );
   std::printf( "  -t, --transform=<name>   try `--transform=help' for a list of names\n" );
   std::printf( "  -T, --threshold=<n%%>     threshold for binarization (0-100%%)\n" );
   std::printf( "  -u, --cut=<l,t,w,h>      cut input image by given rectangle\n" );
   std::printf( "  -v, --verbose            be verbose\n" );
-  std::printf( "  -x <file>                export OCR Results File to <file>\n" );
+  std::printf( "  -x, --export=<file>      export OCR Results File to <file>\n" );
   if( verbosity > 0 )
     {
     std::printf( "  -1..6                    pnm output file type (debug)\n" );
@@ -156,14 +163,14 @@ void show_version() throw()
 const char * my_basename( const char * filename ) throw()
   {
   const char * c = filename;
-  while( *c ) { if( *c == '/' ) filename = c + 1; ++c; }
+  while( *c ) { if( *c == '/' ) { filename = c + 1; } ++c; }
   return filename;
   }
 
 
-int process_file( FILE *infile, const char * infile_name,
+int process_file( FILE * const infile, const char * const infile_name,
                   const Input_control & input_control,
-                  const Control & control ) throw()
+                  const Control & control )
   {
   if( verbosity > 0 )
     std::fprintf( stderr, "processing file `%s'\n", infile_name );
@@ -195,7 +202,7 @@ int process_file( FILE *infile, const char * infile_name,
       if( control.exportfile ) textpage.xprint( control );
       }
     }
-  catch( Page_image::Error e ) { show_error( e.s ); return 2; }
+  catch( Page_image::Error e ) { show_error( e.msg ); return 2; }
   if( verbosity > 0 ) std::fprintf( stderr, "\n" );
   return 0;
   }
@@ -209,7 +216,7 @@ int process_file( FILE *infile, const char * infile_name,
 // image. (or for a pnm file if debugging).
 // 'exportfile' is the Ocr Results File.
 //
-int main( const int argc, const char * argv[] )
+int main( const int argc, const char * const argv[] )
   {
   Input_control input_control;
   Control control;
@@ -235,7 +242,7 @@ int main( const int argc, const char * argv[] )
     { 'h', "help",      Arg_parser::no  },
     { 'i', "invert",    Arg_parser::no  },
     { 'l', "layout",    Arg_parser::no  },
-    { 'o', 0,           Arg_parser::yes },
+    { 'o', "output",    Arg_parser::yes },
     { 'q', "quiet",     Arg_parser::no  },
     { 's', "scale",     Arg_parser::yes },
     { 't', "transform", Arg_parser::yes },
@@ -243,10 +250,10 @@ int main( const int argc, const char * argv[] )
     { 'u', "cut",       Arg_parser::yes },
     { 'v', "verbose",   Arg_parser::no  },
     { 'V', "version",   Arg_parser::no  },
-    { 'x', 0,           Arg_parser::yes },
+    { 'x', "export",    Arg_parser::yes },
     {  0 , 0,           Arg_parser::no  } };
 
-  Arg_parser parser( argc, argv, options );
+  const Arg_parser parser( argc, argv, options );
   if( parser.error().size() )				// bad option
     { show_error( parser.error().c_str(), 0, true ); return 1; }
 
@@ -255,7 +262,7 @@ int main( const int argc, const char * argv[] )
     {
     const int code = parser.code( argind );
     if( !code ) break;					// no more options
-    const char * arg = parser.argument( argind ).c_str();
+    const char * const arg = parser.argument( argind ).c_str();
     switch( code )
       {
       case '1':
@@ -275,7 +282,7 @@ int main( const int argc, const char * argv[] )
                 break;
       case 'f': force = true; break;
       case 'F': if( !control.set_format( arg ) )
-                  { show_error( "bad output format", 0, true ); return 1; }
+                  { show_error( "bad output format.", 0, true ); return 1; }
                 break;
       case 'h': show_help(); return 0;
       case 'i': input_control.invert = true; break;
@@ -287,8 +294,8 @@ int main( const int argc, const char * argv[] )
                   { input_control.transformation.show_error( program_name, arg );
                   return 1; }
                 break;
-      case 'T': if( !input_control.set_threshold( arg ) ) return 1; break;
-      case 'u': if( !input_control.read_cut_rectangle( arg ) ) return 1; break;
+      case 'T': if( !input_control.parse_threshold( arg ) ) return 1; break;
+      case 'u': if( !input_control.parse_cut_rectangle( arg ) ) return 1; break;
       case 'v': if( verbosity < 4 ) ++verbosity; break;
       case 'V': show_version(); return 0;
       case 'x': exportfile_name = arg; break;
@@ -296,6 +303,11 @@ int main( const int argc, const char * argv[] )
       }
     } // end process options
 
+#if defined(__MSVCRT__) || defined(__OS2__) || defined(_MSC_VER)
+  _setmode( fileno( stdin ), O_BINARY );
+  _setmode( fileno( stdout ), O_BINARY );
+#endif
+
   if( outfile_name && std::strcmp( outfile_name, "-" ) != 0 )
     {
     if( append ) control.outfile = std::fopen( outfile_name, "a" );
@@ -334,7 +346,7 @@ int main( const int argc, const char * argv[] )
     }
 
   // process any remaining command line arguments (input files)
-  FILE *infile = (argind < parser.arguments()) ? 0 : stdin;
+  FILE * infile = (argind < parser.arguments()) ? 0 : stdin;
   const char *infile_name = "-";
   int retval = 0;
   while( true )
