@@ -1,5 +1,5 @@
 /*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010
+    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011
     Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
@@ -104,7 +104,7 @@ public:
   int trunc() const throw() { return ( num / den ); }
 
   int parse( const char * const s ) throw();
-  const std::string to_decimal( const unsigned int iwidth = 1, int prec = -2 ) const throw();
+  const std::string to_decimal( const unsigned int iwidth = 1, int prec = -2 ) const;
   };
 
 
