@@ -1,5 +1,5 @@
 /*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009
+    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011
     Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
@@ -35,7 +35,8 @@
 
 namespace {
 
-int find_space_or_hyphen( const std::vector< Character * > & cpv, unsigned int i ) throw()
+int find_space_or_hyphen( const std::vector< Character * > & cpv,
+                          unsigned int i ) throw()
   {
   while( i < cpv.size() && !cpv[i]->maybe(' ') && !cpv[i]->maybe('-') ) ++i;
   return i;
@@ -44,7 +45,7 @@ int find_space_or_hyphen( const std::vector< Character * > & cpv, unsigned int i
 } // end namespace
 
 
-void Textline::recognize2( const Charset & charset ) throw()
+void Textline::recognize2( const Charset & charset )
   {
   if( big_initials() >= characters() ) return;
 
@@ -218,23 +219,26 @@ void Textline::recognize2( const Charset & charset ) throw()
     }
 
   // separate merged characters recognized by recognize1
-  for( int i = big_initials(); i < characters(); )		// FIXME this block sucks
+  for( int i = big_initials(); i < characters(); )
     {
-    if( !cpv[i]->guesses() || cpv[i]->guess( 0 ).code != 0 ) { ++i; continue; }
-    Character c( *cpv[i] );
+    if( !cpv[i]->guesses() || cpv[i]->guess( 0 ).code >= 0 ) { ++i; continue; }
+    const Character c( *cpv[i] );
+    const int blob_index = -(c.guess( 0 ).code + 1);
     delete_character( i );
-    if( c.guesses() >= 3 && c.blobs() >= 1 )
+    if( c.guesses() >= 3 && c.blobs() >= 1 && blob_index < c.blobs() )
       {
       int left = c.guess( 0 ).value;
       for( int g = 1; g < c.guesses(); ++g )
         {
-        Blob & b = c.blob( c.blobs() - 1 );
+        Blob b( c.blob( blob_index ) );
         Rectangle re( left, b.top(), c.guess( g ).value, b.bottom() );
         b.add_rectangle( re );
-        Blob b1( b, re ); b1.adjust_height(); b1.find_holes();
+        Blob b1( b, re );
+        b1.adjust_height(); b1.adjust_width(); b1.find_holes();
         Character c1( new Blob( b1 ) );
-        for( int k = 0; k < c.blobs() - 1; ++k )
-          if( !c.blob( k ).includes( re ) && re.includes_hcenter( c.blob( k ) ) )
+        for( int k = 0; k < c.blobs(); ++k )
+          if( k != blob_index && !c.blob( k ).includes( re ) &&
+              re.includes_hcenter( c.blob( k ) ) )
             c1.shift_blobp( new Blob( c.blob( k ) ) );
         c1.add_guess( c.guess( g ).code, 0 );
         shift_characterp( new Character( c1 ) );
