@@ -1,5 +1,5 @@
 /*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010
+    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011
     Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
@@ -32,7 +32,7 @@ void error( const char * const msg ) throw()
 
 
 int good_reference( const Rectangle & r1, const Rectangle & r2, int & val,
-                    int mean_height, int mean_width ) throw()
+                    const int mean_height, const int mean_width ) throw()
   {
   if( 4 * r1.height() >= 3 * mean_height &&
       4 * r2.height() >= 3 * mean_height &&
@@ -56,7 +56,7 @@ int good_reference( const Rectangle & r1, const Rectangle & r2, int & val,
 
 
 int set_l( const std::vector< Rectangle > & rectangle_vector,
-           int mean_height, int mean_width ) throw()
+           const int mean_height, const int mean_width ) throw()
   {
   const int rectangles = rectangle_vector.size();
   const int imax = rectangles / 4;
@@ -73,7 +73,7 @@ int set_l( const std::vector< Rectangle > & rectangle_vector,
 
 
 int set_r( const std::vector< Rectangle > & rectangle_vector,
-           int mean_height, int mean_width ) throw()
+           const int mean_height, const int mean_width ) throw()
   {
   const int rectangles = rectangle_vector.size();
   const int imin = rectangles - 1 - ( rectangles / 4 );
@@ -215,7 +215,7 @@ bool Vrhomboid::includes( const int row, const int col ) const throw()
 
 // rectangle_vector must be ordered by increasing hcenter().
 //
-void Track::set_track( const std::vector< Rectangle > & rectangle_vector ) throw()
+void Track::set_track( const std::vector< Rectangle > & rectangle_vector )
   {
   if( data.size() ) data.clear();
   if( !rectangle_vector.size() ) return;
